# yapecs
[![PyPI](https://img.shields.io/pypi/v/yapecs.svg)](https://pypi.python.org/pypi/yapecs)
[![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Downloads](https://pepy.tech/badge/yapecs)](https://pepy.tech/project/yapecs)

Yet Another Python Experiment Configuration System (YAPECS)

Documentation can be found [here](https://maxrmorrison.github.io/yapecs/).
